@@ -1,15 +1,17 @@
 def get_all_pairwise_surface_errors(list_mesh_names, location_meshes):
     errors = np.zeros((len(list_mesh_names), len(list_mesh_names)))
     for mesh_idx_1, mesh_name_1 in enumerate(list_mesh_names):
-        print('Beginning Mesh: {},\t{}/{}'.format(mesh_name_1,
-                                                  mesh_idx_1 + 1,
-                                                  len(list_mesh_names)))
+        print(
+            "Beginning Mesh: {},\t{}/{}".format(mesh_name_1, mesh_idx_1 + 1, len(list_mesh_names))
+        )
         starting_idx_2 = mesh_idx_1 + 1
         for mesh_idx_2 in range(starting_idx_2, len(list_mesh_names)):
             mesh_name_2 = list_mesh_names[mesh_idx_2]
-            print('Begining Second Mesh: {},\t{}/{}'.format(mesh_name_2,
-                                                            mesh_idx_2,
-                                                            len(list_mesh_names)))
+            print(
+                "Begining Second Mesh: {},\t{}/{}".format(
+                    mesh_name_2, mesh_idx_2, len(list_mesh_names)
+                )
+            )
             mesh_1 = read_vtk(os.path.join(location_meshes, mesh_name_1))
             mesh_2 = read_vtk(os.path.join(location_meshes, mesh_name_2))
 
@@ -25,4 +27,4 @@ def get_all_pairwise_surface_errors(list_mesh_names, location_meshes):
             print(errors[mesh_idx_1, mesh_idx_2])
             print(errors[mesh_idx_2, mesh_idx_1])
 
-    return errors
\ No newline at end of file
+    return errors
